@@ -32,9 +32,9 @@ def test_python_api0():
     pub = mFed.register_publication("publication", h.HELICS_DATA_TYPE_STRING, "custom-units")
     assert """HelicsPublication(name = "TestFederate/publication", type = "string", units = "custom-units", info = "")""" in repr(pub)
 
-    sub = mFed.register_subscription("subscription", "custom-units")
+    sub = mFed.register_subscription("TestFederate/publication", "custom-units")
     assert (
-        """HelicsInput(name = "_input_3", units = "custom-units", injection_units = "", publication_type = "", type = "", target = "subscription", info = "")"""
+        """HelicsInput(name = "_input_3", units = "custom-units", injection_units = "", publication_type = "", type = "", target = "TestFederate/publication", info = "")"""
         in repr(sub)
     )
     assert (
@@ -45,16 +45,13 @@ def test_python_api0():
     sub.option[h.HELICS_HANDLE_OPTION_CONNECTION_REQUIRED] = 1
     assert sub.option["CONNECTION_REQUIRED"] == 1
 
-    sub.add_target("")
-
     mFed.property[h.HELICS_PROPERTY_TIME_DELTA] = 1.0
     assert mFed.property[h.HELICS_PROPERTY_TIME_DELTA] == 1.0
 
     mFed.property["TIME_DELTA"] = 1.0
     assert mFed.property["TIME_DELTA"] == 1.0
 
-    with pt.raises(h.HelicsException):
-        mFed.enter_executing_mode()
+    mFed.enter_executing_mode()
 
     h.helicsCloseLibrary()
 
@@ -119,6 +116,7 @@ def test_python_api1():
     sub.set_default([1.0, 2.0, 3.0])
     assert sub.vector == [1.0, 2.0, 3.0]
 
+    sub.set_default([complex(1.0, 2.0), complex(3.0, 4.0), complex(5.0, 6.0)])
     sub.info = "hello world"
     assert sub.info == "hello world"
 
@@ -145,9 +143,10 @@ def test_python_api1():
 
     assert mFed.request_time(2.0) == 1.0
 
+    assert mFed.subscriptions["TestFederate/publication"].value == "first-time"
     try:
         assert mFed.subscriptions["TestFederate/publication"].bytes == b"first-time"
-    except Exception as _:
+    except Exception:
         # TODO: this does not work as expected
         with pt.raises(AssertionError):
             assert mFed.subscriptions["TestFederate/publication"].bytes == b"first-time"
@@ -176,6 +175,7 @@ def test_python_api1():
     )
 
     message.append("-random")
+    assert message.is_valid() is True
     assert message.data == "random-data-random"
 
     message.data = "random-data"
@@ -184,6 +184,7 @@ def test_python_api1():
     message.raw_data = b"random-data-random"
     assert message.data == "random-data-random"
 
+    assert message.is_valid() is True
     message.message_id = 100
     message.source = "earth"
     message.destination = "moon"
@@ -191,6 +192,7 @@ def test_python_api1():
     message.original_destination = "goodbye-world"
     message.time = 2.0
 
+    assert message.is_valid() is True
     assert message.message_id == 100
     assert message.source == "earth"
     assert message.destination == "moon"
@@ -198,10 +200,12 @@ def test_python_api1():
     assert message.original_destination == "goodbye-world"
     assert message.time == 2.0
 
+    assert message.is_valid() is True
     assert (
         """<{ 1 = False, 2 = False, 3 = False, 4 = False, 5 = False, 6 = False, 7 = False, 8 = False, 9 = False, 10 = False, 11 = False, 12 = False, 13 = False, 14 = False, 15 = False }>"""
         in repr(message.flag)
     )
+    assert message.is_valid() is True
     message.flag[1] = True
     assert message.flag[1] is True
 
@@ -227,7 +231,13 @@ def test_python_api1():
 
     assert mFed.request_next_step() == 4.0
 
-    assert mFed.subscriptions["TestFederate/publication"].vector == [1.0, 2.0, 3.0, 4.0, 5.0]
+    assert mFed.subscriptions["TestFederate/publication"].vector == [
+        1.0,
+        2.0,
+        3.0,
+        4.0,
+        5.0,
+    ]
 
     mFed.publications["TestFederate/publication"].publish(False)
 
@@ -248,7 +258,7 @@ def test_python_api1():
         in repr(m)
     )
 
-    mFed.finalize()
+    mFed.disconnect()
 
     del mFed
     del broker
@@ -256,7 +266,7 @@ def test_python_api1():
 
 def test_python_api2():
 
-    broker = h.helicsCreateBroker("zmq", "broker", "--federates 1 --loglevel 1")
+    broker = h.helicsCreateBroker("zmq", "broker", "--federates 1 --loglevel=warning")
     assert broker.is_connected()
 
     broker.set_global("hello", "world")
@@ -488,7 +498,7 @@ def test_python_api4():
 
     fi.broker_init = "-f 3"
 
-    fi.flag[h.HelicsFederateFlag.TERMINATE_ON_ERROR] = True
+    fi.flag[h.HelicsFlag.TERMINATE_ON_ERROR] = True
     fi.property[h.HelicsProperty.TIME_DELTA] = 1.0
     fi.property["TIME_DELTA"] = 1.0
 
@@ -585,8 +595,8 @@ def test_python_api7():
     fed.log_message("debug", logging.DEBUG)
     fed.log_message("summary", h.HELICS_LOG_LEVEL_SUMMARY)
 
-    fed.finalize_async()
-    fed.finalize_complete()
+    fed.disconnect_async()
+    fed.disconnect_complete()
 
     fed.core.disconnect()
     assert fed.core.wait_for_disconnect()
@@ -598,3 +608,45 @@ def test_python_api7():
 
     h.helicsCleanupLibrary()
     h.helicsCloseLibrary()
+
+
+def test_python_api8():
+
+    broker = h.helicsCreateBroker("zmq", "", "-f 1 --name=mainbroker")
+
+    cfed = h.helicsCreateCombinationFederateFromConfig(os.path.join(CURRENT_DIRECTORY, "combinationfederate.json"))
+
+    assert len(cfed.endpoints) == 2
+    assert len(cfed.subscriptions) == 2
+
+    h.helicsFederateDestroy(cfed)
+    h.helicsFederateFree(cfed)
+    h.helicsBrokerDestroy(broker)
+    h.helicsCloseLibrary()
+
+
+def test_python_api9():
+
+    broker = h.helicsCreateBroker("zmq", "", "-f 1 --name=mainbroker")
+    fedinfo = h.helicsCreateFederateInfo()
+    assert "HelicsFederateInfo()" in repr(fedinfo)
+    fedinfo.core_name = "TestFederate"
+    fedinfo.core_type = "zmq"
+    fedinfo.core_init = "-f 1 --broker=mainbroker"
+    mFed = h.helicsCreateCombinationFederate("TestFederate", fedinfo)
+
+    pub = mFed.register_publication("publication", h.HELICS_DATA_TYPE_COMPLEX_VECTOR, "custom-units")
+    assert pub.type == "complex_vector"
+
+    sub = mFed.register_subscription("TestFederate/publication", "custom-units")
+    sub.set_default([complex(1.0, 2.0), complex(3.0, 4.0), complex(5.0, 6.0)])
+
+    mFed.enter_executing_mode()
+
+    assert sub.publication_type == "complex_vector"
+    print(sub.value)
+
+    mFed.disconnect()
+
+    del mFed
+    del broker
